#include "spi.h"

/********************
    Init SPI 1
********************/
void INIT_SPI(BYTE speed)
{
    char dummy;     //Temp Dummy Variable
   //Speed can be 0 for 200KHz or 1 for 23MHz
   
   PINSEL0 |= 0x20000000;
   PINSEL1 |= 0x140;

   SSPCR1 = 0x00; //Normal Operation, Master, OFF
   
   if(speed == 0)
   {
     //200Khz Slow Init Mode
     SSPCR0 = 0x1607; //8 bits, SPI, MODE 00, SCR 34
     SSPCPSR = 10; //10 is our divisor CPSDVSR
   }
   else
   {
     //23MHz High Speed Mode
     SSPCR0 = 0x0107; //8 bits, SPI, MODE 00, SCR 0
     SSPCPSR = 4; //4 is our divisor CPSDVSR
   }
   
   SSPCR1 |= 0x02; //Normal Operation, Master, ON
   
    dummy = S0SPDR;     //Dummy Read
}
/********************
    Send Byte VIA SPI1
********************/
BYTE xmit_spi(BYTE data)
{
    BYTE temp;
    while(!(SSPSR & 0x02));
    SSPDR = data;      
    while(!(SSPSR & 0x04));
    temp = SSPDR ;        
    return temp;          
}
/********************
    Get Byte VIA SPI1
********************/
BYTE rcv_spi (void)
 {
    BYTE temp;  
    SSPDR = 0xFF;      
    while(!(SSPSR & 0x04));
    temp = SSPDR ;        
    return temp;          
}
/********************
    SSEL0 = Selected (LOW)
********************/
void SELECT(void)
{
    IO0CLR = SD_CS;      // Set SSEL aka CD line low
    rcv_spi();                  // Send out pulses to clear the port
}
/********************
    SSEL0 = Deselected (High)
********************/
void DESELECT(void)
{
    IO0SET = SD_CS;      // Set SSEL aka CD line High 
}
/********************
    Deselect the card and release SPI bus          
********************/
void release_spi (void)
{
    DESELECT();         //Deselect 
    rcv_spi();               // Send out pulses to clear the port
}
/********************
    Detect Card
********************/
char CheckSD(void)
{
  if(SD_CD==1)
  {
//    Delay_MS(10);
    return 1;
  }
  return 0;
}